@@ -4,11 +4,23 @@ import sass
 from ..options import Options
 
 
+def _css_escape(text: str) -> str:
+    """ @see https://developer.mozilla.org/en-US/docs/Web/CSS/string """
+
+    if not text:
+        return ''
+
+    # -- probably not needed.
+    # text = text.encode('unicode-escape').decode('ascii').replace('\\u', '\\')
+
+    return text.replace("'", '\\27')
+
+
 def style_for_print(options: Options) -> str:
     scss = f"""
     :root {{
-        string-set: author '{options.author}';
-        string-set: copyright '{options.copyright}';
+        string-set: author '{_css_escape(options.author)}';
+        string-set: copyright '{_css_escape(options.copyright)}';
     }}
     h1, h2, h3 {{
         string-set: chapter content();
